@@ -75,6 +75,7 @@ extern "C" {
 #include "asterisk/dsp.h"
 #include "asterisk/uuid.h"
 
+struct a02_container;
 struct ast_bridge_technology;
 struct ast_bridge;
 struct ast_bridge_tech_optimizations;
@@ -171,6 +172,8 @@ struct ast_bridge_video_mode {
  * \brief Destroy the bridge.
  *
  * \param self Bridge to operate upon.
+ *
+ * \return Nothing
  */
 typedef void (*ast_bridge_destructor_fn)(struct ast_bridge *self);
 
@@ -184,6 +187,8 @@ typedef void (*ast_bridge_destructor_fn)(struct ast_bridge *self);
  * references to the bridge so it can be destroyed.
  *
  * \note On entry, self must NOT be locked.
+ *
+ * \return Nothing
  */
 typedef void (*ast_bridge_dissolving_fn)(struct ast_bridge *self);
 
@@ -219,6 +224,8 @@ typedef int (*ast_bridge_push_channel_fn)(struct ast_bridge *self, struct ast_br
  * bridge_channel->bridge_pvt.
  *
  * \note On entry, self is already locked.
+ *
+ * \return Nothing
  */
 typedef void (*ast_bridge_pull_channel_fn)(struct ast_bridge *self, struct ast_bridge_channel *bridge_channel);
 
@@ -233,6 +240,8 @@ typedef void (*ast_bridge_pull_channel_fn)(struct ast_bridge *self, struct ast_b
  * to re-evaluate this a channel in the bridge.
  *
  * \note On entry, self is already locked.
+ *
+ * \return Nothing
  */
 typedef void (*ast_bridge_notify_masquerade_fn)(struct ast_bridge *self, struct ast_bridge_channel *bridge_channel);
 
@@ -307,6 +316,41 @@ struct ast_bridge_softmix {
 
 AST_LIST_HEAD_NOLOCK(ast_bridge_channels_list, ast_bridge_channel);
 
+/*!
+ * \brief Structure that contains a snapshot of information about a bridge
+ */
+struct ast_bridge_snapshot {
+	AST_DECLARE_STRING_FIELDS(
+		/*! Immutable bridge UUID. */
+		AST_STRING_FIELD(uniqueid);
+		/*! Bridge technology that is handling the bridge */
+		AST_STRING_FIELD(technology);
+		/*! Bridge subclass that is handling the bridge */
+		AST_STRING_FIELD(subclass);
+		/*! Creator of the bridge */
+		AST_STRING_FIELD(creator);
+		/*! Name given to the bridge by its creator */
+		AST_STRING_FIELD(name);
+		/*! Unique ID of the channel providing video, if one exists */
+		AST_STRING_FIELD(video_source_id);
+	);
+	/*! AO2 container of bare channel uniqueid strings participating in the bridge.
+	 * Allocated from ast_str_container_alloc() */
+	struct ao2_container *channels;
+	/*! Bridge flags to tweak behavior */
+	struct ast_flags feature_flags;
+	/*! Bridge capabilities */
+	uint32_t capabilities;
+	/*! Number of channels participating in the bridge */
+	unsigned int num_channels;
+	/*! Number of active channels in the bridge. */
+	unsigned int num_active;
+	/*! The video mode of the bridge */
+	enum ast_bridge_video_mode_type video_mode;
+	/*! The time of bridge creation */
+	struct timeval creationtime;
+};
+
 /*!
  * \brief Structure that contains information about a bridge
  */
@@ -320,7 +364,7 @@ struct ast_bridge {
 	/*! Private information unique to the bridge technology */
 	void *tech_pvt;
 	/*! Per-bridge topics */
-	struct stasis_cp_single *topics;
+	struct stasis_topic *topic;
 	/*! Call ID associated with the bridge */
 	ast_callid callid;
 	/*! Linked list of channels participating in the bridge */
@@ -366,6 +410,8 @@ struct ast_bridge {
 
 	/*! Type mapping used for media routing */
 	struct ast_vector_int media_types;
+	/*! Current bridge snapshot */
+	struct ast_bridge_snapshot *current_snapshot;
 	/*! The time of bridge creation */
 	struct timeval creationtime;
 };
@@ -373,6 +419,19 @@ struct ast_bridge {
 /*! \brief Bridge base class virtual method table. */
 extern struct ast_bridge_methods ast_bridge_base_v_table;
 
+/*!
+ * \brief Returns the global bridges container
+ * \since 17.0
+ *
+ * \retval a pointer to the bridges container success
+ * \retval NULL on failure
+ *
+ * \note You must use ao2_ref(<container>, -1) when done with it
+ *
+ * \warning You must not attempt to modify the container returned.
+ */
+struct ao2_container *ast_bridges(void);
+
 /*!
  * \brief Create a new base class bridge
  *
@@ -382,7 +441,7 @@ extern struct ast_bridge_methods ast_bridge_base_v_table;
  * \param name Name given to the bridge by its creator (optional, requires named creator)
  * \param id Unique ID given to the bridge by its creator (optional)
  *
- * \return a pointer to a new bridge on success
+ * \retval a pointer to a new bridge on success
  * \retval NULL on failure
  *
  * Example usage:
@@ -415,6 +474,8 @@ static inline int _ast_bridge_trylock(struct ast_bridge *bridge, const char *fil
  * \brief Lock the bridge.
  *
  * \param bridge Bridge to lock
+ *
+ * \return Nothing
  */
 #define ast_bridge_lock(bridge)	_ast_bridge_lock(bridge, __FILE__, __PRETTY_FUNCTION__, __LINE__, #bridge)
 static inline void _ast_bridge_lock(struct ast_bridge *bridge, const char *file, const char *function, int line, const char *var)
@@ -426,6 +487,8 @@ static inline void _ast_bridge_lock(struct ast_bridge *bridge, const char *file,
  * \brief Unlock the bridge.
  *
  * \param bridge Bridge to unlock
+ *
+ * \return Nothing
  */
 #define ast_bridge_unlock(bridge)	_ast_bridge_unlock(bridge, __FILE__, __PRETTY_FUNCTION__, __LINE__, #bridge)
 static inline void _ast_bridge_unlock(struct ast_bridge *bridge, const char *file, const char *function, int line, const char *var)
@@ -476,6 +539,8 @@ int ast_bridge_destroy(struct ast_bridge *bridge, int cause);
  * \since 12.0.0
  *
  * \param chan Channel just involved in a masquerade
+ *
+ * \return Nothing
  */
 void ast_bridge_notify_masquerade(struct ast_channel *chan);
 
@@ -738,6 +803,8 @@ int ast_bridge_move(struct ast_bridge *dst_bridge, struct ast_bridge *src_bridge
  * \param bridge What to operate on.
  * \param request Inhibit request increment.
  *     (Positive to add requests.  Negative to remove requests.)
+ *
+ * \return Nothing
  */
 void ast_bridge_merge_inhibit(struct ast_bridge *bridge, int request);
 
@@ -793,9 +860,10 @@ int ast_bridge_unsuspend(struct ast_bridge *bridge, struct ast_channel *chan);
  *
  * \pre chan must be locked before calling
  *
- * \param chan channel name of the bridged peer
- * \param name
+ * \param name channel name of the bridged peer
  * \param pvtid Private CallID of the bridged peer
+ *
+ * \return nothing
  */
 void ast_bridge_vars_set(struct ast_channel *chan, const char *name, const char *pvtid);
 
@@ -851,7 +919,7 @@ enum ast_bridge_optimization {
  * AST_BRIDGE_OPTIMIZE_PROHIBITED guarantees that an optimization attempt will
  * never succeed.
  *
- * \return Optimization allowability for the bridges
+ * \returns Optimization allowability for the bridges
  */
 enum ast_bridge_optimization ast_bridges_allow_optimization(struct ast_bridge *chan_bridge,
 		struct ast_bridge *peer_bridge);
@@ -988,7 +1056,7 @@ void ast_bridge_set_remb_estimated_bitrate(struct ast_bridge *bridge, float esti
 /*!
  * \brief Update information about talker energy for talker src video mode.
  */
-void ast_bridge_update_talker_src_video_mode(struct ast_bridge *bridge, struct ast_channel *chan, int talker_energy, int is_keyframe);
+void ast_bridge_update_talker_src_video_mode(struct ast_bridge *bridge, struct ast_channel *chan, int talker_energy, int is_keyfame);
 
 /*!
  * \brief Returns the number of video sources currently active in the bridge
@@ -999,7 +1067,7 @@ int ast_bridge_number_video_src(struct ast_bridge *bridge);
  * \brief Determine if a channel is a video src for the bridge
  *
  * \retval 0 Not a current video source of the bridge.
- * \retval non-zero is a video source of the bridge, The number
+ * \retval None 0, is a video source of the bridge, The number
  *         returned represents the priority this video stream has
  *         on the bridge where 1 is the highest priority.
  */
@@ -1015,7 +1083,7 @@ void ast_bridge_remove_video_src(struct ast_bridge *bridge, struct ast_channel *
  *
  * \param video_mode The video mode
  *
- * \return A string representation of \c video_mode
+ * \retval A string representation of \c video_mode
  */
 const char *ast_bridge_video_mode_to_string(enum ast_bridge_video_mode_type video_mode);
 
@@ -1213,6 +1281,8 @@ struct ast_channel *ast_bridge_peer(struct ast_bridge *bridge, struct ast_channe
  *
  * \param features Bridge features structure
  * \param flags Determinator for whether hook is removed.
+ *
+ * \return Nothing
  */
 void ast_bridge_features_remove(struct ast_bridge_features *features, enum ast_bridge_hook_remove_flags flags);
 
