@@ -248,7 +248,7 @@ int ast_base64encode(char *dst, const unsigned char *src, int srclen, int max);
  * \param src The source buffer
  *
  * \retval NULL on failure
- * \return Encoded string on success
+ * \retval Encoded string on success
  */
 char *ast_base64encode_string(const char *src);
 
@@ -272,7 +272,7 @@ int ast_base64decode(unsigned char *dst, const char *src, int max);
  * \param src The source buffer
  *
  * \retval NULL on failure
- * \return Decoded string on success
+ * \retval Decoded string on success
  */
 char *ast_base64decode_string(const char *src);
 
@@ -320,7 +320,7 @@ int ast_base64url_encode(char *dst, const unsigned char *src, int srclen, int ma
  * \param src The source buffer
  *
  * \retval NULL on failure
- * \return Decoded string on success
+ * \retval Decoded string on success
  */
 char *ast_base64url_decode_string(const char *src);
 
@@ -332,30 +332,10 @@ char *ast_base64url_decode_string(const char *src);
  * \param src The source data to be encoded
  *
  * \retval NULL on failure
- * \return Encoded string on success
+ * \retval Encoded string on success
  */
 char *ast_base64url_encode_string(const char *src);
 
-/*!
- * \brief Performs a base 64 encode algorithm on the contents of a File
- * \param inputfile A FILE handle to the input file to be encoded. Must be readable. This handle is not automatically closed.
- * \param outputfile A FILE handle to the output file to receive the base 64 encoded contents of the input file, identified by filename.
- * \param endl The line ending to use (e.g. either "\n" or "\r\n")
- *
- * \return zero on success, -1 on error.
- */
-int ast_base64_encode_file(FILE *inputfile, FILE *outputfile, const char *endl);
-
-/*!
- * \brief Performs a base 64 encode algorithm on the contents of a File
- * \param filename The path to the file to be encoded. Must be readable, file is opened in read mode.
- * \param outputfile A FILE handle to the output file to receive the base 64 encoded contents of the input file, identified by filename.
- * \param endl The line ending to use (e.g. either "\n" or "\r\n")
- *
- * \return zero on success, -1 on error.
- */
-int ast_base64_encode_file_path(const char *filename, FILE *outputfile, const char *endl);
-
 #define AST_URI_ALPHANUM     (1 << 0)
 #define AST_URI_MARK         (1 << 1)
 #define AST_URI_UNRESERVED   (AST_URI_ALPHANUM | AST_URI_MARK)
@@ -405,8 +385,8 @@ void ast_uri_decode(char *s, struct ast_flags spec);
 	\param string String to be converted
 	\param outbuf Resulting encoded string
 	\param buflen Size of output buffer
-	\retval 0 for success
-	\retval -1 if buflen is too short.
+	\return 0 for success
+	\return -1 if buflen is too short.
  */
 int ast_xml_escape(const char *string, char *outbuf, size_t buflen);
 
@@ -621,6 +601,7 @@ long int ast_random(void);
 /*!
  * \brief Disable PMTU discovery on a socket
  * \param sock The socket to manipulate
+ * \return Nothing
  *
  * On Linux, UDP sockets default to sending packets with the Dont Fragment (DF)
  * bit set. This is supposedly done to allow the application to do PMTU
@@ -636,8 +617,7 @@ void ast_enable_packet_fragmentation(int sock);
  * \brief Recursively create directory path
  * \param path The directory path to create
  * \param mode The permissions with which to try to create the directory
- * \retval 0 on success
- * \return error code otherwise
+ * \return 0 on success or an error code otherwise
  *
  * Creates a directory path, creating parent directories as needed.
  */
@@ -650,11 +630,9 @@ int ast_mkdir(const char *path, int mode);
  * If \a base_path does not exist, it will not be created and this function
  * returns \c EPERM.
  *
- * \param base_path
  * \param path The directory path to create
  * \param mode The permissions with which to try to create the directory
- * \retval 0 on success
- * \return an error code otherwise
+ * \return 0 on success or an error code otherwise
  */
 int ast_safe_mkdir(const char *base_path, const char *path, int mode);
 
@@ -666,8 +644,7 @@ int ast_safe_mkdir(const char *base_path, const char *path, int mode);
  * \param v the value to check
  * \param min minimum lower bound (inclusive)
  * \param max maximum upper bound (inclusive)
- * \retval 0 if value out of bounds
- * \retval non-zero otherwise
+ * \return 0 if value out of bounds, otherwise true (non-zero)
  */
 #define IN_BOUNDS(v, min, max) ((v) >= (min)) && ((v) <= (max))
 
@@ -676,8 +653,7 @@ int ast_safe_mkdir(const char *base_path, const char *path, int mode);
  *
  * \param v the value to check
  * \param a the array to bound check
- * \retval 0 if value out of bounds
- * \retval non-zero otherwise
+ * \return 0 if value out of bounds, otherwise true (non-zero)
  */
 #define ARRAY_IN_BOUNDS(v, a) IN_BOUNDS((int) (v), 0, ARRAY_LEN(a) - 1)
 
@@ -699,7 +675,7 @@ struct ast_http_digest {
 
 /*!
  * \brief Parse digest authorization header.
- * \return -1 if we have no auth or something wrong with digest.
+ * \return Returns -1 if we have no auth or something wrong with digest.
  * \note This function may be used for Digest request and responce header.
  * request arg is set to nonzero, if we parse Digest Request.
  * pedantic arg can be set to nonzero if we need to do addition Digest check.
@@ -744,6 +720,8 @@ static void force_inline _ast_assert(int condition, const char *condition_str, c
  * \brief Force a crash if DO_CRASH is defined.
  *
  * \note If DO_CRASH is not defined then the function returns.
+ *
+ * \return Nothing
  */
 void DO_CRASH_NORETURN ast_do_crash(void);
 
@@ -835,8 +813,7 @@ char *ast_eid_to_str(char *s, int maxlen, struct ast_eid *eid);
  * This function expects an EID in the format:
  *    00:11:22:33:44:55
  *
- * \retval 0 success
- * \retval non-zero failure
+ * \return 0 success, non-zero failure
  * \since 1.6.1
  */
 int ast_str_to_eid(struct ast_eid *eid, const char *s);
@@ -844,8 +821,7 @@ int ast_str_to_eid(struct ast_eid *eid, const char *s);
 /*!
  * \brief Compare two EIDs
  *
- * \retval 0 if the two are the same
- * \retval non-zero otherwise
+ * \return 0 if the two are the same, non-zero otherwise
  * \since 1.6.1
  */
 int ast_eid_cmp(const struct ast_eid *eid1, const struct ast_eid *eid2);
@@ -853,8 +829,7 @@ int ast_eid_cmp(const struct ast_eid *eid1, const struct ast_eid *eid2);
 /*!
  * \brief Check if EID is empty
  *
- * \retval 1 if the EID is empty
- * \retval 0 otherwise
+ * \return 1 if the EID is empty, zero otherwise
  * \since 13.12.0
  */
 int ast_eid_is_empty(const struct ast_eid *eid);
@@ -954,7 +929,7 @@ static inline void _raii_cleanup_block(_raii_cleanup_block_t *b) { (*b)(); }
  * \param key User's password to crypt.
  * \param salt Salt to crypt with.
  * \return Crypted password.
- * \retval NULL on error.
+ * \return \c NULL on error.
  */
 char *ast_crypt(const char *key, const char *salt);
 
@@ -967,7 +942,7 @@ char *ast_crypt(const char *key, const char *salt);
  *
  * \param key User's password to crypt.
  * \return Crypted password.
- * \retval NULL on error.
+ * \return \c NULL on error.
  */
 char *ast_crypt_encrypt(const char *key);
 
@@ -976,8 +951,8 @@ char *ast_crypt_encrypt(const char *key);
  *
  * \param key User's password to validate.
  * \param expected Expected result from crypt.
- * \retval True (non-zero) if \a key matches \a expected.
- * \retval False (zero) if \a key doesn't match.
+ * \return True (non-zero) if \a key matches \a expected.
+ * \return False (zero) if \a key doesn't match.
  */
 int ast_crypt_validate(const char *key, const char *expected);
 
@@ -986,8 +961,8 @@ int ast_crypt_validate(const char *key, const char *expected);
  * \since 13.7.0
  *
  * \param filename File to test.
- * \retval True (non-zero) if the file exists and is readable.
- * \retval False (zero) if the file either doesn't exists or is not readable.
+ * \return True (non-zero) if the file exists and is readable.
+ * \return False (zero) if the file either doesn't exists or is not readable.
  */
 int ast_file_is_readable(const char *filename);
 
@@ -995,12 +970,12 @@ int ast_file_is_readable(const char *filename);
  * \brief Compare 2 major.minor.patch.extra version strings.
  * \since 13.7.0
  *
- * \param version1
- * \param version2
+ * \param version1.
+ * \param version2.
  *
- * \retval negative if version 1 < version 2.
- * \retval 0 if version 1 = version 2.
- * \retval positive if version 1 > version 2.
+ * \return <0 if version 1 < version 2.
+ * \return =0 if version 1 = version 2.
+ * \return >0 if version 1 > version 2.
  */
 int ast_compare_versions(const char *version1, const char *version2);
 
@@ -1008,8 +983,8 @@ int ast_compare_versions(const char *version1, const char *version2);
  * \brief Test that an OS supports IPv6 Networking.
  * \since 13.14.0
  *
- * \retval True (non-zero) if the IPv6 supported.
- * \retval False (zero) if the OS doesn't support IPv6.
+ * \return True (non-zero) if the IPv6 supported.
+ * \return False (zero) if the OS doesn't support IPv6.
  */
 int ast_check_ipv6(void);
 
@@ -1028,8 +1003,8 @@ enum ast_fd_flag_operation {
  * \param fd File descriptor to set flags on
  * \param flags The flag(s) to set
  *
- * \retval -1 on error
- * \retval 0 if successful
+ * \return -1 on error
+ * \return 0 if successful
  */
 #define ast_fd_set_flags(fd, flags) \
 	__ast_fd_set_flags((fd), (flags), AST_FD_FLAG_SET, __FILE__, __LINE__, __PRETTY_FUNCTION__)
@@ -1044,8 +1019,8 @@ enum ast_fd_flag_operation {
  * \param fd File descriptor to clear flags on
  * \param flags The flag(s) to clear
  *
- * \retval -1 on error
- * \retval 0 if successful
+ * \return -1 on error
+ * \return 0 if successful
  */
 #define ast_fd_clear_flags(fd, flags) \
 	__ast_fd_set_flags((fd), (flags), AST_FD_FLAG_CLEAR, __FILE__, __LINE__, __PRETTY_FUNCTION__)
@@ -1092,27 +1067,17 @@ int ast_pipe_nonblock(int filedes[2]);
  *
  * \param is_user_interface Non-zero to mark the thread as a user interface.
  *
- * \retval True (non-zero) if marking current thread failed.
- * \retval False (zero) if successfuly marked current thread.
+ * \return 0 if successfuly marked current thread.
+ * \return Non-zero if marking current thread failed.
  */
 int ast_thread_user_interface_set(int is_user_interface);
 
 /*!
  * \brief Indicates whether the current thread is a user interface
  *
- * \retval True (non-zero) if thread is a user interface.
- * \retval False (zero) if thread is not a user interface.
+ * \return True (non-zero) if thread is a user interface.
+ * \return False (zero) if thread is not a user interface.
  */
 int ast_thread_is_user_interface(void);
 
-/*!
- * \brief Test for the presence of an executable command in $PATH
- *
- * \param cmd Name of command to locate.
- *
- * \retval True (non-zero) if command is in $PATH.
- * \retval False (zero) command not found.
- */
-int ast_check_command_in_path(const char *cmd);
-
 #endif /* _ASTERISK_UTILS_H */
